@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.108_04';
+our $VERSION = '0.109_01';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Tue Oct 16 20:35:54 2018 GMT
+# on Fri Oct 19 13:51:37 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1769,7 +1769,7 @@ __PACKAGE__->status( add => 25527, iridium => '-', 'Iridium 2', 'Tumbling' );
 __PACKAGE__->status( add => 25528, iridium => 'D', 'Iridium 86', 'Decayed 2018-10-05' );
 __PACKAGE__->status( add => 25529, iridium => 'D', 'Iridium 85', 'Decayed 2000-12-30' );
 __PACKAGE__->status( add => 25530, iridium => '-', 'Iridium 84', 'Tumbling' );
-__PACKAGE__->status( add => 25531, iridium => 'S', 'Iridium 83', '' );
+__PACKAGE__->status( add => 25531, iridium => '-', 'Iridium 83', 'Tumbling' );
 __PACKAGE__->status( add => 25577, iridium => '-', 'Iridium 20', 'Tumbling' );
 __PACKAGE__->status( add => 25578, iridium => '-', 'Iridium 11', 'Tumbling' );
 __PACKAGE__->status( add => 25777, iridium => '+', 'Iridium 14', '' );
@@ -1784,8 +1784,8 @@ __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-0
 
 # Summary:
 # Operational [+]: 8
-#       Spare [S]: 10
-#    Tumbling [-]: 36
+#       Spare [S]: 9
+#    Tumbling [-]: 37
 #     Decayed [D]: 43
 
 1;
